var Protocol = function()
{
	var protocol = {};
	var debug = 0;
	
	var lysatesIsValid = false;

	// Page initialization
	protocol.initPage = function()
	{
		var pageId = Doc.getPageId();
		if (pageId == 'protocol')
		{
			Buttons.addClickHandler('print-button', Wizard.goPrint);	
			Doc.show('all-protocol');
			
			var url = '../Extraction.servlet?ID='+App.getSessionId();
			url += '&cmd=GetLatestReagentLotNumbers';		
			Wizard.showLoadingAnimation('Loading recent reagent lot numbers...');
			Wizard.asyncJsonRequest(url, protocol.reagentsLoaded);
			
			Events.addEventHandler('showReagents', 'click', protocol.toggleReagents);
		}
		else
		{
			Events.addEventHandler('lysates', 'change', protocol.lysatesOnChange);
			Buttons.addClickHandler('gocreate', protocol.viewProtocol);

			var url = '../Extraction.servlet?ID='+App.getSessionId();
			url += '&cmd=GetUnprocessedLysates';
			Wizard.showLoadingAnimation('Loading Lysate extracts...');
			Wizard.asyncJsonRequest(url, protocol.initializeStep1);
		}
	}


	protocol.initializeStep1 = function(response)
	{
		var frm = document.forms['reggie'];	
		var lysates = response.lysates;
		
		var lysateList = frm.lysates;
		if (lysates.length > 0)
		{
			for (var i=0; i < lysates.length; i++)
			{
				var lysate = lysates[i];
				var name = (i+1) + ': ' + Strings.encodeTags(lysate.name);
				if (lysate.bioWell)
				{
					name += ' -- ' + Strings.encodeTags(lysate.bioWell.bioPlate.name + ' (' + lysate.bioWell.location+')');
				}
				var selected = i < 12;
				var option = new Option(name, lysate.id, selected, selected);
				option.lysate = lysate;
				lysateList.options[lysateList.length] = option;
			}
			protocol.lysatesOnChange();
		}
		else
		{	
			Wizard.setFatalError('No Lysate available for processing.');
			return;
		}
		
		Doc.show('step-1');
		Doc.show('gocreate');
	}
	

	// Add pools to the pools list based on the bioplate selection
	protocol.lysatesOnChange = function()
	{
		lysatesIsValid = false;
		
		var frm = document.forms['reggie'];
		var lysateList = frm.lysates;
		
		var numSelected = 0;
		for (var i = 0; i < lysateList.length; i++)
		{
			if (lysateList[i].selected) numSelected++;
		}
		
		if (numSelected != 12)
		{
			Wizard.setInputStatus('lysate', 'invalid', 'Must select 12 items.');
			return;
		}
		
		lysatesIsValid = true;
		Wizard.setInputStatus('lysate', 'valid');
	}
	
	protocol.viewProtocol = function()
	{
		var frm = document.forms['reggie'];
		if (!lysatesIsValid)
		{
			Wizard.notifyError();
			return;
		}
		frm.submit();
	}

	protocol.reagentsLoaded = function(response)
	{
		var rna = response.rna;
		var lysate = response.lysate;
		if (rna) 
		{
			protocol.fillLatestReagents(rna);
			Doc.element('latestQiaCubeDate').innerHTML = Reggie.reformatDate(rna.QiaCubeDate);
			Doc.show('showLatestReagents', 'inline');
		}
		if (lysate) protocol.fillLatestReagents(lysate);
	}
	
	protocol.fillLatestReagents = function(item)
	{
		for (var rg in item)
		{
			if (item[rg] != null)
			{
				var e = Doc.element(rg);
				if (e)
				{
					e.innerHTML = Strings.encodeTags(item[rg]);
				}
				
			}
		}
	}
	
	protocol.toggleReagents = function(event)
	{
		Doc.addOrRemoveClass(document.body, 'hide-reagents', !event.currentTarget.checked);
	}

	return protocol;
}();

Doc.onLoad(Protocol.initPage);

